@@ -4,9 +4,9 @@ use core::iter;
 
 use crate::error::InvalidFormatDescription;
 use crate::format_description::parse::{
-    attach_location, unused, Error, ErrorInner, Location, Spanned, SpannedValue, Unused,
+    Error, ErrorInner, Location, Spanned, SpannedValue, Unused, attach_location, unused,
 };
-use crate::format_description::{self, modifier, BorrowedFormatItem, Component};
+use crate::format_description::{self, BorrowedFormatItem, Component, modifier};
 
 /// Parse a sequence of items from the [`strftime` format description][strftime docs].
 ///
@@ -119,9 +119,13 @@ fn lex(mut input: &[u8]) -> iter::Peekable<impl Iterator<Item = Result<Token<'_>
 }
 
 #[inline]
-fn into_items<'iter, 'token: 'iter, I: Iterator<Item = Result<Token<'token>, Error>> + 'iter>(
+fn into_items<'iter, 'token, I>(
     mut tokens: iter::Peekable<I>,
-) -> impl Iterator<Item = Result<BorrowedFormatItem<'token>, Error>> + use<'iter, 'token, I> {
+) -> impl Iterator<Item = Result<BorrowedFormatItem<'token>, Error>> + use<'token, I>
+where
+    'token: 'iter,
+    I: Iterator<Item = Result<Token<'token>, Error>> + 'iter,
+{
     iter::from_fn(move || {
         let next = match tokens.next()? {
             Ok(token) => token,
@@ -323,7 +327,7 @@ fn parse_component(
                     context: "",
                     index: component.span.start.byte as usize,
                 },
-            })
+            });
         }
         b'p' => component!(Period {
             is_uppercase: true,
@@ -473,7 +477,7 @@ fn parse_component(
                     context: "",
                     index: component.span.start.byte as usize,
                 },
-            })
+            });
         }
         _ => {
             return Err(Error {
@@ -485,7 +489,7 @@ fn parse_component(
                     name: String::from_utf8_lossy(&[*component]).into_owned(),
                     index: component.span.start.byte as usize,
                 },
-            })
+            });
         }
     })
 }
